@@ -93,7 +93,7 @@ class BespinSpec(object):
             , tags = dictionary_spec()
 
             , stack_json = filename_spec(formatted(defaulted(string_spec(), "{config_root}/{_key_name_1}.json"), formatter=MergedOptionStringFormatter))
-            , params_json = optional_spec(filename_spec(formatted(defaulted(string_spec(), "{config_root}/{environment}/{_key_name_1}-params.json"), formatter=MergedOptionStringFormatter)))
+            , params_json = filename_spec(formatted(defaulted(string_spec(), "{config_root}/{environment}/{_key_name_1}-params.json"), formatter=MergedOptionStringFormatter))
 
             , build_after = listof(formatted(string_spec(), formatter=MergedOptionStringFormatter))
             , ignore_deps = defaulted(boolean(), False)
@@ -153,7 +153,7 @@ class BespinSpec(object):
 
             , extra = defaulted(formatted_string, "")
             , region = defaulted(string_spec(), "ap-southeast-2")
-            , no_assume_role = formatted_boolean
+            , no_assume_role = defaulted(formatted_boolean, False)
 
             , chosen_task = defaulted(formatted_string, "list_tasks")
             , chosen_stack = defaulted(formatted_string, "")
