@@ -229,7 +229,8 @@ class Overview(object):
                 action = name
             return (name, Task(action, description=description, options=options, label="Bespin"))
         return dict([
-              t("show", "Show the available stacks")
+              t("execute", "Execute a command with assumed creds")
+            , t("show", "Show the available stacks")
             , t("deploy", "Deploy a particular stack")
             , t("bastion", "SSH into the bastion")
             , t("instances", "Find and ssh into the instances")
